@@ -464,18 +464,19 @@ class QuoteData(object):
                 cols_fn = c
             if type(cols_fn) is str:
                 cols_fn = [cols_fn]
+            cols_fn = [x.lower() for x in cols_fn]
             if not cols_fn:
                 raise Exception('columns name not support.')
 
             # 字段重名处理
             if [x for x in cols_fn if x in cols_techansi]:
-                c_arr = [str(x) for x in v]
+                c_arr = [str(x).lower() for x in v]
                 if len(cols_fn) > 1:
-                    c_arr.insert(0, c)
+                    c_arr.insert(0, c.lower())
                     cols_fn = ['_'.join(c_arr) + '_' + x for x in cols_fn]
                 elif len(cols_fn) == 1:
-                    if cols_fn[0] == c:
-                        c_arr.insert(0, c)
+                    if cols_fn[0] == c.lower():
+                        c_arr.insert(0, c.lower())
                         cols_fn = ['_'.join(c_arr)]
                     else:
                         c_arr.insert(0, cols_fn[0])
@@ -498,18 +499,21 @@ class QuoteData(object):
             pool.close()
             pool.join()
 
-            df[cols_techansi] = np.nan
+            for x in cols_techansi:
+                df[x] = np.nan
             for cols_fn, result in tasks:
                 se = result.get()
                 se.dropna(inplace=True)
                 if not se.empty:
                     df.loc[se.index, cols_fn] = se.tolist() if len(cols_fn) > 1 else se
         else:
+            for x in cols_techansi:
+                df[x] = np.nan
             for cols_fn, func, kw in operate_params:
                 se = _arithmetic_worker(df, func, kw)
                 se.dropna(inplace=True)
                 if not se.empty:
-                    df[cols_fn] = pd.DataFrame(se.tolist(), index=se.index) if len(cols_fn) > 1 else se
+                    df.loc[se.index, cols_fn] = se.tolist() if len(cols_fn) > 1 else se
 
         # self.trace('exec', time.time() - proc_start)
         return df
@@ -803,7 +807,8 @@ class QuoteData(object):
                         sec_num[c] += 1
                         if sec_num[c] < count:
                             continue
-                        sec_list.remove(c)
+                        if c in sec_list:
+                            sec_list.remove(c)
                 # self.execute_rehabilitation(df, fq, fq_vol, columns=cols_retain, inplace=True)
                 result = result.append(df, ignore_index=True)
                 if check_security_count:
